#include "filter.h"

// IIr filter module. It implements a first order IIR filter.

#if IIR_FILTER_ENABLE
WORD ApplyIIRFilter(BYTE SensorNo, WORD Average_value)
{
	static BYTE initialization = 1;  
	static WORD PreviousOutput[CSDPLUS_TotalSensorCount];
	long unsigned int Output=0;
	BYTE Coeff;
	
	Output = PreviousOutput[SensorNo]; 		//Store yi-1 in variable "Output'
	if(initialization)			
	{	
		PreviousOutput[SensorNo] = Average_value;
		initialization = 0;
	}
	else
	{
		
		Coeff = IIR_COEFF_PROX; 
		
		// Apply filter =n: yi = (xi+(k-1)*yi-1)/k
		Output *= (Coeff-1) ; 				//Output = (k-1)*yi-1
		Output = Output + CSDPLUS_waSnsResult[SensorNo] ; 				//Output = xi+(k-1)*yi-1
		Output = Output/Coeff;				//Output = (xi+(k-1)*yi-1)/k
		
		PreviousOutput[SensorNo] = (WORD)Output;			//yi = Output
	}	
	return PreviousOutput[SensorNo];
}
#endif


// Average filter module.This filter finds the average of the (AVERAGING_ORDER) number of samples. 

#if AVERAGE_FILTER_ENABLE
WORD ApplyAveragingFilter(BYTE SensorNo)
{
	BYTE iteration;	
	long unsigned int Filtered_RCs=0x00;
	static WORD Averaging_History[AVERAGING_ORDER][CSDPLUS_TotalSensorCount];
	static BYTE FlagFirstCall[CSDPLUS_TotalSensorCount]= {0};
	
	if(!FlagFirstCall[SensorNo])
	{
		for (iteration = 0; iteration < AVERAGING_ORDER ; iteration++)
		{
			Averaging_History[iteration][SensorNo] = CSDPLUS_waSnsResult[SensorNo];	
		}
		FlagFirstCall[SensorNo]++;
		Filtered_RCs = CSDPLUS_waSnsResult[SensorNo];
	}
	else
	{
		for (iteration = 0; iteration < AVERAGING_ORDER-1 ; iteration++)
		{
			Averaging_History[iteration][SensorNo] = Averaging_History[iteration+1][SensorNo];	
			Filtered_RCs += Averaging_History[iteration][SensorNo];
		}
		Averaging_History[AVERAGING_ORDER-1][SensorNo] = CSDPLUS_waSnsResult[SensorNo];
		Filtered_RCs += Averaging_History[AVERAGING_ORDER-1][SensorNo];
		Filtered_RCs /= AVERAGING_ORDER;
	}
	return((WORD) Filtered_RCs);
}
#endif

// Median filter module/ This filter finds the median of (MEDIAN_ORDER) number of samples.

#if MEDIAN_FILTER_ENABLE
WORD ApplyMedianfilter(WORD Input)
{
	BYTE iteration, comparison;
	WORD wTemp;
	static WORD History[MEDIAN_FILTER_ORDER];
	static BYTE SampleCount = 0; 
	WORD wTempHistorySort[MEDIAN_FILTER_ORDER];
	
	if(0 == SampleCount)
	{
		SampleCount = 1;
		for (iteration = 0; iteration < MEDIAN_FILTER_ORDER-1 ; iteration++)
		{
			History[iteration] = 0;
			wTempHistorySort[iteration]= 0;
		}
		History[MEDIAN_FILTER_ORDER-1] = Input;
		return Input; 
	}
	else
	{
		for (iteration = 0; iteration < MEDIAN_FILTER_ORDER-1 ; iteration++)
		{
			History[iteration] = History[iteration+1];	
			wTempHistorySort[iteration]= History[iteration];
		}
		wTempHistorySort[MEDIAN_FILTER_ORDER-1]= History[MEDIAN_FILTER_ORDER-1] = Input;
	
		/*Bubble sort*/
		for (iteration = MEDIAN_FILTER_ORDER-1; iteration>0 ; iteration--)
		{
			for(comparison = 0; comparison<iteration; comparison++)
			{
				if(wTempHistorySort[comparison]>wTempHistorySort[comparison+1])
				{
					wTemp = wTempHistorySort[comparison] ;
					wTempHistorySort[comparison] = wTempHistorySort[comparison+1];
					wTempHistorySort[comparison+1] = wTemp;
				}
			}
		}
		
		if(SampleCount < MEDIAN_FILTER_ORDER)
		{
			SampleCount++;
			return(wTempHistorySort[MEDIAN_FILTER_ORDER - ((SampleCount-1) >> 1) - 1]);
		}
		else
		{
			return(wTempHistorySort[MEDIAN_FILTER_ORDER>>1]);
		}
	}
}
#endif