//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

//I2C buffer structure
struct I2C_Regs
{
	BYTE bSensorIndex;	
	WORD wSensorRawCount;
	WORD wSensorBaseline; 	
	WORD wSensorDiffCount;
	BYTE bButtonState;	
	BYTE bSliderCentroid;
	
} MyI2C_Regs;

void main(void)
{
	WORD wSliderCentroid;
	
	M8C_EnableGInt;//turn on global interrupts
	
	//setup RAM buffer
	EzI2Cs_SetRamBuffer(sizeof(MyI2C_Regs), 1, (BYTE *)&MyI2C_Regs);
	EzI2Cs_Start(); //Turn ON I2C
	
	SmartSense_Start(); //Start SmartSense user module.
	SmartSense_InitializeBaselines(); //Initialize BaseLines for all the Sensors.

	while (1) 
	{ 
		SmartSense_ScanAllSensors(); //Scan all the Capacitive sensors
		SmartSense_UpdateAllBaselines(); //Update the baselines of all sensors
		SmartSense_bIsAnySensorActive(); // Detect if any sensor is pressed
		
		wSliderCentroid = SmartSense_wGetCentroidPos(1);
		/*
		if ((SmartSense_bIsSensorActive(0)) || (SmartSense_bIsSensorActive(2)) || (SmartSense_bIsSensorActive(4)) ) //check if SLD0/SLD2/SLD4 is active, turn the respective LED ON
		{
		PRT2DR |= 0x20;
		}
		else if ((!(SmartSense_bIsSensorActive(0))) && (!(SmartSense_bIsSensorActive(2))) && (!(SmartSense_bIsSensorActive(4))) )//Turn OFF the LED if the respective sensors are OFF
		{
		PRT2DR &= ~0x20;
		}
		if ((SmartSense_bIsSensorActive(1)) || (SmartSense_bIsSensorActive(3))) //check if SLD1 is active, turn the respective LED ON
		{
		PRT2DR |= 0x08;
		}
		else if ((!(SmartSense_bIsSensorActive(1))) && (!(SmartSense_bIsSensorActive(3))))//Turn OFF the LED if the respective sensors are OFF
		{
		PRT2DR &= ~0x08;
		} */
	
	
		EzI2Cs_DisableInt(); //Disable I2C interrupt while the buffer is being updated		
		if(!(EzI2Cs_bBusy_Flag == EzI2Cs_I2C_BUSY_RAM_READ))
		{			
			MyI2C_Regs.wSensorRawCount = SmartSense_waSnsResult[MyI2C_Regs.bSensorIndex]; // Storing Sensor RawCounts
			MyI2C_Regs.wSensorBaseline = SmartSense_waSnsBaseline[MyI2C_Regs.bSensorIndex]; // Storing Sensor Baseline
			MyI2C_Regs.wSensorDiffCount = SmartSense_waSnsDiff[MyI2C_Regs.bSensorIndex]; // Storing Sensor DiffCount
			MyI2C_Regs.bButtonState = ((SmartSense_baSnsOnMask[0] >> MyI2C_Regs.bSensorIndex) & 0x01); //Storing Sensor ON/OFF status
			MyI2C_Regs.bSliderCentroid = wSliderCentroid; // Storing Slider Centroid
		}		
		EzI2Cs_ResumeInt(); //Re-enable the I2C interrupt
	} 
		
}			
		
		
		
		
		

